## Description
Library used to implement the International Brain Laboratory data pipeline.
The library as currently 3 main modules:
-   **alf**: the ALF
-   **ibllib**: general purpose library containng I/O, signal processing and IBL data pipelines utilities.
-   **oneibl**: interface to the Alyx database of experiments to access IBL data.

## Documentation
https://ibllib.readthedocs.io/en/latest/

## Installation
https://ibllib.readthedocs.io/en/latest/01b_installation_general.html#

## Demonstration
https://ibllib.readthedocs.io/en/latest/_static/one_demo.html

## Requirements
**OS**: Linux and Windows. Untested on Mac.

**Python Module**: Python 3.6 or higher.

## Development practices
Gitflow and Semantic Versioning.

Python
-   run tests
-   flake8
-   build documentation


## Matlab Library
The Matlab library has moved to its own repository here: https://github.com/int-brain-lab/ibllib-matlab/
